/*
 * Copyright (C) 2004,2005 Charles Schmidt <cschmidt2@emich.edu>
 * Copyright (C) 2006 INDT
 *  Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*
 */

#ifndef __DMAP_CONNECTION_H__
#define __DMAP_CONNECTION_H__

#include <glib.h>
#include <glib-object.h>

#include <math.h>

#include <libsoup/soup.h>

#include <libdmapsharing/dmap-item.h>

G_BEGIN_DECLS

#define TYPE_DMAP_CONNECTION         (dmap_connection_get_type ())
#define DMAP_CONNECTION(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_DMAP_CONNECTION, DMAPConnection))
#define DMAP_CONNECTION_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), TYPE_DMAP_CONNECTION, DMAPConnectionClass))
#define IS_DMAP_CONNECTION(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_DMAP_CONNECTION))
#define IS_DMAP_CONNECTION_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_DMAP_CONNECTION))
#define DMAP_CONNECTION_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_DMAP_CONNECTION, DMAPConnectionClass))

typedef struct _DMAPConnection        DMAPConnection;
typedef struct _DMAPConnectionClass   DMAPConnectionClass;
typedef struct _DMAPConnectionPrivate DMAPConnectionPrivate;

typedef enum {
    DMAP_CONNECTION_ERROR_NONE,
    DMAP_CONNECTION_ERROR_GENERIC,
    DMAP_CONNECTION_ERROR_FORBIDDEN,
    DMAP_CONNECTION_ERROR_SERVICE_UNAVAILABLE
} DMAPConnectionError;

struct _DMAPConnectionClass {
    GObjectClass parent;

    /* callbacks */
    SoupMessage * (* build_message)    (DMAPConnection *self,
                                        SoupURI *base_uri,
                                        const gchar *path,
                                        gboolean need_hash,
                                        gdouble version,
                                        gint req_id);
    DMAPItem    * (* create_root_item) (DMAPConnection *self);

    /* signals */
    gchar       * (* authenticate)     (DMAPConnection *self,
                                        const gchar *name);
    void          (* connected   )     (DMAPConnection *self);
    void          (* disconnected)     (DMAPConnection *self);
    void          (* error)            (DMAPConnection *self,
                                        DMAPConnectionError error);
};

struct _DMAPConnection {
    GObject parent;

    DMAPConnectionPrivate *priv;
};

typedef void (* DMAPResponseHandler) (DMAPConnection *self,
                                      guint status,
                                      GNode *structure,
                                      gpointer user_data);

GType         dmap_connection_get_type               (void);

gboolean      dmap_connection_connect                (DMAPConnection *self);
void          dmap_connection_disconnect             (DMAPConnection *self);

gboolean      dmap_connection_get                    (DMAPConnection *self,
                                                      const gchar *path,
                                                      gboolean need_hash,
                                                      DMAPResponseHandler handler,
                                                      gpointer user_data);

gdouble       dmap_connection_get_protocol_version   (DMAPConnection *self);
guint32       dmap_connection_get_session_id         (DMAPConnection *self);
gint          dmap_connection_get_database_id        (DMAPConnection *self);
gint          dmap_connection_get_revision_number    (DMAPConnection *self);
DMAPItem     *dmap_connection_get_root_item          (DMAPConnection *self);

G_END_DECLS

#endif
